# PESummary

[![Pipeline Status](https://git.ligo.org/lscsoft/pesummary/badges/master/pipeline.svg)](https://git.ligo.org/lscsoft/pesummary/commits/master)
[![Coverage report](https://docs.ligo.org/lscsoft/pesummary/coverage_badge.svg)](https://docs.ligo.org/lscsoft/pesummary/htmlcov/index.html)
[![Python versions](https://img.shields.io/pypi/pyversions/pesummary.svg)](https://img.shields.io/pypi/pyversions/pesummary.svg)

This package helps the user to generate summary webpages to visualise the output from any sample generating code.

 * [Installation instructions](https://docs.ligo.org/lscsoft/pesummary/installation.html)
 * [Documentation](https://docs.ligo.org/lscsoft/pesummary)
 * [Issue Tracker](https://git.ligo.org/lscsoft/pesummary/issues)
